| Supported Targets | ESP32-S3 |
| ----------------- | -------- |

# GC9B71 LCD Example

This example shows how to use GC9B71 display driver. These components are using API provided by `esp_lcd` component. This example will display LVGL demos.

**Important Notes**:

1. This example relies on some new features that have not yet been merged into ESP-IDF. To successfully compile it, you will need to apply the patch, see [here](#idf-requirements).

## IDF Requirements

* ESP-IDF: **release/v5.1** branch, use `git checkout --recurse-submodules 25876e8f49` switch to the commit **25876e8f49**
* Patch: go to the root folder of ESP-IDF, use `git apply <path_of_patch>/esp_lcd-support-QSPI-mode_25876e8f49.patch` to apply the [patch](patch/esp_lcd-support-QSPI-mode_25876e8f49.patch).

## How to use the example

### Hardware Required

* An ESP development board
* An GC9B71 LCD panel, with QSPI interface
* An USB cable for power supply and programming

### Hardware Connection

The connection between ESP Board and the LCD is as follows:

```
       ESP Board                       GC9B71 Panel (QSPI)
┌──────────────────────┐              ┌────────────────────┐
│             GND      ├─────────────►│ GND                │
│                      │              │                    │
│             3V3      ├─────────────►│ VCC                │
│                      │              │                    │
│             GND      ├─────────────►│ RS                 │
│                      │              │                    │
│             CS       ├─────────────►│ CS                 │
│                      │              │                    │
│             SCK      ├─────────────►│ CLK                │
│                      │              │                    │
│             D3       ├─────────────►│ IO3                │
│                      │              │                    │
│             D2       ├─────────────►│ IO2                │
│                      │              │                    │
│             D1       ├─────────────►│ IO1                │
│                      │              │                    │
│             D0       ├─────────────►│ IO0                │
│                      │              │                    │
│             RST      ├─────────────►│ RSTN               │
│                      │              │                    │
│             (SCL)    ├─────────────►│ TP_SCL             │
│                      │              │                    │
│             (SDA)    ├─────────────►│ TP_SDA             │
│                      │              │                    │
│             (TP_INT) ├─────────────►│ TP_INT             │
│                      │              │                    │
│             (3V3)    ├─────────────►│ TP_RST             │
│                      │              │                    │
└──────────────────────┘              └────────────────────┘
```

### Software Configuration

* The LCD parameters and GPIO number used by this example can be changed in [esp-bsp.h](components/bsp/include/bsp/esp-bsp.h).
* The example also uses the touch panel (cst816s) of the LCD, but it is not necessary. If you don't need it, you can set macro `USE_TOUCH_PANEL` to 0 in [esp-bsp.h](components/bsp/include/bsp/esp-bsp.h).
* Especially, please pay attention to the **vendor specific initialization**, it can be different between manufacturers and should consult the LCD supplier for initialization sequence code. You can change the code `vendor_config` in [bsp.c](components/bsp/bsp.c).

### Build and Flash

Run `idf.py set-target esp32s3` to choose the target chip.

Run `idf.py -p PORT build flash monitor` to build, flash and monitor the project. A fancy animation will show up on the LCD as expected.

The first time you run `idf.py` for the example will cost extra time as the build system needs to address the component dependencies and downloads the missing components from registry into `managed_components` folder.

(To exit the serial monitor, type ``Ctrl-]``.)

See the [Getting Started Guide](https://docs.espressif.com/projects/esp-idf/en/latest/get-started/index.html) for full steps to configure and use ESP-IDF to build projects.

### Example Output

```bash
...
I (419) bsp: Initialize SPI bus
I (423) bsp: Install panel IO
I (426) bsp: Install LCD driver of gc9b71
I (431) gpio: GPIO[17]| InputEn: 0| OutputEn: 1| OpenDrain: 0| Pullup: 0| Pulldown: 0| Intr:0
I (710) bsp: Starting LVGL task
I (739) app_main: Display LVGL demo
...
```

## Troubleshooting

For any technical queries, please open an [issue] (https://github.com/espressif/esp-iot-solution/issues) on GitHub. We will get back to you soon.
