# ESP LCD GC9B71

[![Component Registry](https://components.espressif.com/components/espressif/esp_lcd_gc9b71/badge.svg)](https://components.espressif.com/components/espressif/esp_lcd_gc9b71)

Implementation of the GC9B71 LCD controller with [esp_lcd](https://docs.espressif.com/projects/esp-idf/en/latest/esp32s3/api-reference/peripherals/lcd.html) component.

| LCD controller | Communication interface | Component name |                               Link to datasheet                                |
| :------------: | :---------------------: | :------------: | :----------------------------------------------------------------------------: |
|     GC9B71     |        SPI/QSPI         | esp_lcd_gc9b71 | [link](https://dl.espressif.com/AE/esp-iot-solution/GC9B71_DataSheet_V1.0.pdf) |

## Add to project

Packages from this repository are uploaded to [Espressif's component service](https://components.espressif.com/).
You can add them to your project via `idf.py add-dependancy`, e.g.
```
    idf.py add-dependency esp_lcd_gc9b71==1.0.0
```

Alternatively, you can create `idf_component.yml`. More is in [Espressif's documentation](https://docs.espressif.com/projects/esp-idf/en/latest/esp32/api-guides/tools/idf-component-manager.html).

## Initialization Code

### SPI Interface

```c
    ESP_LOGI(TAG, "Initialize SPI bus");
    const spi_bus_config_t bus_config = ESP_LCD_BUS_SPI_GC9B71_CONFIG(EXAMPLE_LCD_PCLK, EXAMPLE_LCD_DATA0);
    ESP_ERROR_CHECK(spi_bus_initialize(EXAMPLE_LCD_SPI_NUM, &bus_config, SPI_DMA_CH_AUTO));

    ESP_LOGI(TAG, "Install panel IO");
    esp_lcd_panel_io_handle_t io_handle = NULL;
    const esp_lcd_panel_io_spi_config_t io_config = ESP_LCD_IO_SPI_GC9B71_CONFIG(EXAMPLE_LCD_CS, EXAMPLE_LCD_DC, callback, &callback_data);
    ESP_ERROR_CHECK(esp_lcd_new_panel_io_spi((esp_lcd_spi_bus_handle_t)EXAMPLE_LCD_SPI_NUM, &io_config, &io_handle));

    ESP_LOGI(TAG, "Install LCD driver of gc9b71");
    esp_lcd_panel_handle_t panel_handle = NULL;
    const esp_lcd_panel_dev_config_t panel_config = {
        .reset_gpio_num = EXAMPLE_LCD_RST,
        .color_space = ESP_LCD_COLOR_SPACE_RGB,
        .bits_per_pixel = EXAMPLE_LCD_BIT_PER_PIXEL,
        .vendor_config = NULL,
    };
    ESP_ERROR_CHECK(esp_lcd_new_panel_gc9b71(io_handle, &panel_config, &panel_handle));

    esp_lcd_panel_reset(panel_handle);
    esp_lcd_panel_init(panel_handle);
    esp_lcd_panel_disp_on_off(panel_handle, true);
```

### QSPI Interface

```c
    ESP_LOGI(TAG, "Initialize SPI bus");
    const esp_lcd_panel_io_spi_config_t io_config = ESP_LCD_BUS_QSPI_GC9B71_CONFIG(EXAMPLE_LCD_PCLK, EXAMPLE_LCD_DATA0, EXAMPLE_LCD_DATA1, EXAMPLE_LCD_DATA2, EXAMPLE_LCD_DATA3);
    ESP_ERROR_CHECK(spi_bus_initialize(EXAMPLE_LCD_SPI_NUM, &buscfg, SPI_DMA_CH_AUTO));

    ESP_LOGI(TAG, "Install panel IO");
    esp_lcd_panel_io_handle_t io_handle = NULL;
    const esp_lcd_panel_io_spi_config_t io_config = ESP_LCD_IO_QSPI_GC9B71_CONFIG(EXAMPLE_LCD_CS, callback, &callback_data);
    ESP_ERROR_CHECK(esp_lcd_new_panel_io_spi((esp_lcd_spi_bus_handle_t)EXAMPLE_LCD_SPI_NUM, &io_config, &io_handle));

// The array should be declared as static const and positioned outside the function.
// static const lcd_init_cmd_t lcd_init_cmds[] = {
// //   cmd   data        data_size  delay_ms
//     {0x8B, (uint8_t []){0x0A}, 1, 0},
//     {0xEC, (uint8_t []){0x07}, 1, 0},
//     {0x74, (uint8_t []){0x01, 0x80, 0x00, 0x00, 0x00, 0x00}, 6, 0},
//     {0x98, (uint8_t []){0x3E}, 1, 0},
//     {0x99, (uint8_t []){0x3E}, 1, 0},
//     ...
// };

    ESP_LOGI(TAG, "Install LCD driver of gc9b71");
    esp_lcd_panel_handle_t panel_handle = NULL;
    const vendor_config_t vendor_config = {
        // .init_cmds = lcd_init_cmds,         // Only useful when `use_external_init_cmds` is set to 1
        // .init_cmds_size = sizeof(lcd_init_cmds) / sizeof(lcd_init_cmd_t),
        .flags = {
            .quad_mode = 1,
            .use_external_init_cmds = 0,    // Set to 1 if you want to use your own init commands
        },
    };
    const esp_lcd_panel_dev_config_t panel_config = {
        .reset_gpio_num = EXAMPLE_LCD_RST,
        .color_space = ESP_LCD_COLOR_SPACE_RGB,
        .bits_per_pixel = EXAMPLE_LCD_BIT_PER_PIXEL,
        .vendor_config = (void *)&vendor_config,
    };
    ESP_ERROR_CHECK(esp_lcd_new_panel_gc9b71(io_handle, &panel_config, &panel_handle));

    esp_lcd_panel_reset(panel_handle);
    esp_lcd_panel_init(panel_handle);
    esp_lcd_panel_disp_on_off(panel_handle, true);
```
